@@ -1,7 +1,3 @@
-library(textrecipes)
-library(recipes)
-library(tibble)
-
 text <- tibble(text = c(
   "I would not eat them here or there.",
   "I would not eat them anywhere.",
@@ -11,6 +7,7 @@ text <- tibble(text = c(
 
 test_that("lemmatization works", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
 
   rec <- recipe(~text, data = text) %>%
@@ -53,6 +50,7 @@ test_that("lemmatization errors if lemma attribute doesn't exists", {
 
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
 
   tokenized_test_data <- recipe(~text, data = text) %>%
@@ -67,9 +65,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
   
   trained <- prep(rec)
   
-  expect_error(
-    bake(trained, new_data = tokenized_test_data[, -1]),
-    class = "new_data_missing_column"
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = tokenized_test_data[, -1])
   )
 })
 
@@ -112,7 +110,9 @@ test_that("empty selection tidy method works", {
 
 test_that("printing", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
+  
   rec <- recipe(~text, data = text) %>%
     step_tokenize(all_predictors(), engine = "spacyr") %>%
     step_lemma(all_predictors())
