@@ -5,12 +5,12 @@ test_data <- list(
 
 test_that("ngram works with varrying number of `n`", {
   expect_equal(
-    cpp11_ngram(test_data, n = 1L, n_min = 1, delim = "_"),
+    ngram(test_data, n = 1L, n_min = 1, delim = "_"),
     test_data
   )
 
   expect_equal(
-    cpp11_ngram(test_data, n = 2L, n_min = 2L, delim = "_"),
+    ngram(test_data, n = 2L, n_min = 2L, delim = "_"),
     list(
       c("not_eat", "eat_them", "them_here", "here_or", "or_there."),
       c("not_eat", "eat_them", "them_anywhere.")
@@ -18,7 +18,7 @@ test_that("ngram works with varrying number of `n`", {
   )
 
   expect_equal(
-    cpp11_ngram(test_data, n = 3L, n_min = 3L, delim = "_"),
+    ngram(test_data, n = 3L, n_min = 3L, delim = "_"),
     list(
       c("not_eat_them", "eat_them_here", "them_here_or", "here_or_there."),
       c("not_eat_them", "eat_them_anywhere.")
@@ -27,12 +27,12 @@ test_that("ngram works with varrying number of `n`", {
 
   expect_snapshot(
     error = TRUE,
-    cpp11_ngram(test_data, n = 0L, n_min = 0L, delim = "_")
+    ngram(test_data, n = 0L, n_min = 0L, delim = "_")
   )
 
   expect_snapshot(
     error = TRUE,
-    cpp11_ngram(test_data, n = -1L, n_min = -1L, delim = "_")
+    ngram(test_data, n = -1L, n_min = -1L, delim = "_")
   )
 })
 
@@ -45,12 +45,12 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 1, 1, " "),
+    ngram(tknlist, 1, 1, " "),
     tknlist
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 2, 2, " "),
+    ngram(tknlist, 2, 2, " "),
     list(
       c("a b", "b c", "c d", "d e"),
       c("a b"),
@@ -60,7 +60,7 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 3, 3, " "),
+    ngram(tknlist, 3, 3, " "),
     list(
       c("a b c", "b c d", "c d e"),
       character(0),
@@ -70,7 +70,7 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 2, 1, " "),
+    ngram(tknlist, 2, 1, " "),
     list(
       c("a", "b", "c", "d", "e", "a b", "b c", "c d", "d e"),
       c("a", "b", "a b"),
@@ -80,7 +80,7 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 3, 1, " "),
+    ngram(tknlist, 3, 1, " "),
     list(
       c("a", "b", "c", "d", "e", "a b", "b c", "c d", "d e", "a b c", "b c d", "c d e"),
       c("a", "b", "a b"),
@@ -90,7 +90,7 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 
   expect_equal(
-    cpp11_ngram(tknlist, 3, 2, " "),
+    ngram(tknlist, 3, 2, " "),
     list(
       c("a b", "b c", "c d", "d e", "a b c", "b c d", "c d e"),
       c("a b"),
@@ -102,7 +102,7 @@ test_that("tokenlist_ngram works with n_min and n", {
 
 test_that("ngram works with delim", {
   expect_equal(
-    cpp11_ngram(test_data, n = 3L, n_min = 3L, delim = ""),
+    ngram(test_data, n = 3L, n_min = 3L, delim = ""),
     list(
       c("noteatthem", "eatthemhere", "themhereor", "hereorthere."),
       c("noteatthem", "eatthemanywhere.")
@@ -110,7 +110,7 @@ test_that("ngram works with delim", {
   )
 
   expect_equal(
-    cpp11_ngram(test_data, n = 3L, n_min = 3L, delim = " "),
+    ngram(test_data, n = 3L, n_min = 3L, delim = " "),
     list(
       c("not eat them", "eat them here", "them here or", "here or there."),
       c("not eat them", "eat them anywhere.")
@@ -120,24 +120,21 @@ test_that("ngram works with delim", {
 
 test_that("ngram returns length zero vectors when length(x) < n", {
   expect_equal(
-    cpp11_ngram(list(c("a", "b")), n = 3L, n_min = 3L, delim = "_"),
+    ngram(list(c("a", "b")), n = 3L, n_min = 3L, delim = "_"),
     list(character())
   )
 
   expect_equal(
-    cpp11_ngram(list(c("a")), n = 3L, n_min = 3L, delim = "_"),
+    ngram(list(c("a")), n = 3L, n_min = 3L, delim = "_"),
     list(character())
   )
 
   expect_equal(
-    cpp11_ngram(list(character()), n = 3L, n_min = 3L, delim = "_"),
+    ngram(list(character()), n = 3L, n_min = 3L, delim = "_"),
     list(character())
   )
 })
 
-library(recipes)
-library(textrecipes)
-
 test_tibble <- tibble(text = c(
   "not eat them here or there.",
   "not eat them anywhere."
@@ -250,6 +247,27 @@ test_that("tunable", {
   )
 })
 
+test_that("bad args", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_ngram(num_tokens = -4) %>%
+      prep()
+  )
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_ngram(min_num_tokens = -4) %>%
+      prep()
+  )
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_ngram(delim = -4) %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -266,9 +284,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
   
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
   
-  expect_error(
-    bake(trained, new_data = tokenized_test_data[, -1]),
-    class = "new_data_missing_column"
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = tokenized_test_data[, -1])
   )
 })
 
@@ -330,4 +348,4 @@ test_that("tunable is setup to works with extract_parameter_set_dials", {
   
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 1L)
-})
\ No newline at end of file
+})
