@@ -1,7 +1,3 @@
-library(textrecipes)
-library(recipes)
-library(tibble)
-
 text <- tibble(text = c(
   "I would not eat them here or there.",
   "I would not eat them anywhere.",
@@ -11,6 +7,7 @@ text <- tibble(text = c(
 
 test_that("part of speech filtering works", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
 
   rec <- recipe(~text, data = text) %>%
@@ -36,6 +33,7 @@ test_that("part of speech filtering works", {
 
 test_that("part of speech filtering removes everything", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
 
   rec <- recipe(~text, data = text) %>%
@@ -61,6 +59,7 @@ test_that("part of speech filtering removes everything", {
 
 test_that("part of speech filtering works with multiple tags", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
 
   rec <- recipe(~text, data = text) %>%
@@ -95,10 +94,24 @@ test_that("lemmatization errors if lemma attribute doesn't exists", {
   )
 })
 
+test_that("bad args", {
+  skip_on_cran()
+  skip_if_not_installed("spacyr")
+  skip_if_no_python_or_no_spacy()
+  
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_pos_filter(keep_tags = -4) %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
   
   tokenized_test_data <- recipe(~text, data = text) %>%
@@ -113,9 +126,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
   
   trained <- prep(rec)
   
-  expect_error(
-    bake(trained, new_data = tokenized_test_data[, -1]),
-    class = "new_data_missing_column"
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = tokenized_test_data[, -1])
   )
 })
 
@@ -158,11 +171,13 @@ test_that("empty selection tidy method works", {
 
 test_that("printing", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
+
   rec <- recipe(~text, data = text) %>%
     step_tokenize(all_predictors(), engine = "spacyr") %>%
     step_pos_filter(all_predictors())
   
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
-})
\ No newline at end of file
+})
