@@ -1,7 +1,3 @@
-library(testthat)
-library(recipes)
-library(tibble)
-
 ex_dat <- tibble(text = c("sch\U00f6n", "scho\U0308n"))
 
 test_that("simple sqrt trans", {
@@ -17,10 +13,22 @@ test_that("simple sqrt trans", {
   expect_equal(rec_trans$text, factor(exp_res$text))
 })
 
+test_that("bad args", {
+  skip_if_not_installed("stringi")
+
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_text_normalization(normalization_form = "wrong") %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_if_not_installed("stringi")
+  
   rec <- recipe(~text, data = ex_dat) %>%
     step_text_normalization(text) %>%
     update_role(text, new_role = "potato") %>%
@@ -28,9 +36,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
   
   trained <- prep(rec, training = ex_dat, verbose = FALSE)
   
-  expect_error(
-    bake(trained, new_data = ex_dat[, -1]),
-    class = "new_data_missing_column"
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = ex_dat[, -1])
   )
 })
 
@@ -82,4 +90,4 @@ test_that("printing", {
     step_text_normalization(text)
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
-})
\ No newline at end of file
+})
