@@ -1,6 +1,3 @@
-library(recipes)
-library(textrecipes)
-
 test_data <- tibble(text = c(
   "I would not eat them here or there.",
   "I would not eat them anywhere.",
@@ -11,8 +8,6 @@ test_data <- tibble(text = c(
 rec <- recipe(~., data = test_data)
 
 test_that("textfeature extraction is done correctly", {
-  skip_if_not_installed("textfeatures")
-  library(textfeatures)
   rec <- rec %>%
     step_textfeature(text)
 
@@ -32,7 +27,6 @@ test_that("textfeature extraction is done correctly", {
 })
 
 test_that("custom extraction functions work works", {
-  skip_if_not_installed("textfeatures")
   nchar1 <- function(x) nchar(x) + 1
   nchar2 <- function(x) nchar(x) + 2
   nchar3 <- function(x) nchar(x) + 3
@@ -80,6 +74,15 @@ test_that("check_name() is used", {
   )
 })
 
+test_that("bad args", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_textfeature(prefix = NULL) %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -90,9 +93,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
   
   trained <- prep(rec, training = test_data, verbose = FALSE)
   
-  expect_error(
-    bake(trained, new_data = test_data[, -1]),
-    class = "new_data_missing_column"
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = test_data[, -1])
   )
 })
 
@@ -181,15 +184,12 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
   
-  expect_error(
-    bake(rec, new_data = test_data),
-    NA
+  expect_no_error(
+    bake(rec, new_data = test_data)
   )
 })
 test_that("keep_original_cols works", {
-  skip_if_not_installed("textfeatures")
-  
-  new_names <- paste0("textfeature_text_", names(textfeatures::count_functions))
+  new_names <- paste0("textfeature_text_", names(count_functions))
   
   rec <- recipe(~text, data = test_data) %>%
     step_textfeature(text, keep_original_cols = FALSE)
@@ -215,8 +215,6 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  skip_if_not_installed("textfeatures")
-  
   rec <- recipe(~text, data = test_data) %>%
     step_textfeature(text)
   
@@ -226,18 +224,16 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
   
-  expect_error(
-    bake(rec, new_data = test_data),
-    NA
+  expect_no_error(
+    bake(rec, new_data = test_data)
   )
 })
 
 
 test_that("printing", {
-  skip_if_not_installed("textfeatures")
   rec <- rec %>%
     step_textfeature(text)
   
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
-})
\ No newline at end of file
+})
