@@ -1,6 +1,3 @@
-library(textrecipes)
-library(recipes)
-
 text <- c(
   "I would not eat them here or there.",
   "I would not eat them anywhere.",
@@ -10,6 +7,7 @@ text <- c(
 
 test_that("tokenizer works", {
   skip_on_cran()
+  skip_if_not_installed("spacyr")
   skip_if_no_python_or_no_spacy()
   out <- spacyr_tokenizer_words(text)
 
